"use strict";
var _dndCore = require("dnd-core");
var _vue = require("@testing-library/vue");
var _dndContext = require("../DndContext");
var _dndProviderVue = _interopRequireDefault(require("../DndProvider.vue"));
var _reactDndTestBackend = require("react-dnd-test-backend");
var _vue1 = require("vue");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
describe('DndProvider', function() {
    afterEach(_vue.cleanup);
    it('reuses DragDropManager provided to it', function() {
        var capturedManager;
        var manager = (0, _dndCore).createDragDropManager(_reactDndTestBackend.TestBackend, {}, {});
        var ChildComponent = (0, _vue1).defineComponent(function() {
            capturedManager = (0, _dndContext).useDndContextInjector();
            return function() {
                return null;
            };
        });
        var TestComponent = (0, _vue1).defineComponent(function() {
            return function() {
                return (0, _vue1).h(_dndProviderVue.default, {
                    manager: manager
                }, [
                    (0, _vue1).h(ChildComponent)
                ]);
            };
        });
        (0, _vue).render(TestComponent);
        expect(capturedManager).toBe(manager);
    });
    it('stores DragDropManager in global context and cleans up on unmount', function() {
        var capturedManager;
        var ChildComponent = (0, _vue1).defineComponent(function() {
            capturedManager = (0, _dndContext).useDndContextInjector();
            return function() {
                return null;
            };
        });
        var TestProvider = (0, _vue1).defineComponent(function() {
            return function() {
                return (0, _vue1).h(_dndProviderVue.default, {
                    backend: _reactDndTestBackend.TestBackend
                }, [
                    (0, _vue1).h(ChildComponent)
                ]);
            };
        });
        var mountProvider = function() {
            return (0, _vue).render(TestProvider);
        };
        var globalInstance = function() {
            return global[Symbol.for('__VUE_DND_CONTEXT_INSTANCE__')];
        };
        // Single mount & unmount works
        var root = mountProvider();
        expect(globalInstance()).toEqual(capturedManager);
        root.unmount();
        expect(globalInstance()).toEqual(null);
        // Two mounted components do a refcount
        var rootA = mountProvider();
        var rootB = mountProvider();
        expect(globalInstance()).toEqual(capturedManager);
        rootA.unmount();
        expect(globalInstance()).toEqual(capturedManager);
        rootB.unmount();
        expect(globalInstance()).toEqual(null);
    });
});
